@@ -10,6 +10,7 @@ from vdb.lib import config as config
 from vdb.lib import db as dbLib
 from vdb.lib.gha import GitHubSource
 from vdb.lib.nvd import NvdSource
+from vdb.lib.osv import OSVSource
 
 from depscan.lib import utils as utils
 from depscan.lib.analysis import (
@@ -22,7 +23,7 @@ from depscan.lib.analysis import (
 )
 from depscan.lib.audit import audit, risk_audit, risk_audit_map, type_audit_map
 from depscan.lib.bom import create_bom, get_pkg_by_type, get_pkg_list
-from depscan.lib.config import license_data_dir
+from depscan.lib.config import license_data_dir, spdx_license_list
 from depscan.lib.license import build_license_data, bulk_lookup
 from depscan.lib.logger import LOG, console
 
@@ -43,7 +44,7 @@ def build_args():
     Constructs command line arguments for the vulndb tool
     """
     parser = argparse.ArgumentParser(
-        description="Fully open-source security audit for project dependencies based on known vulnerabilities and advisories."
+        description="Fully open-source security and license audit for application dependencies and container images based on known vulnerabilities and advisories."
     )
     parser.add_argument(
         "--no-banner",
@@ -98,7 +99,10 @@ def build_args():
         help="Examine using the given Software Bill-of-Materials (SBoM) file in CycloneDX format. Use cdxgen command to produce one.",
     )
     parser.add_argument(
-        "-i", "--src", dest="src_dir_image", help="Source directory or container image"
+        "-i",
+        "--src",
+        dest="src_dir_image",
+        help="Source directory or container image or binary file",
     )
     parser.add_argument(
         "-o",
@@ -226,15 +230,22 @@ def main():
     if not args.no_banner:
         print(at_logo)
     src_dir = args.src_dir_image
-    reports_base_dir = "."
     if not src_dir:
         src_dir = os.getcwd()
+    reports_base_dir = src_dir
     # Detect the project types and perform the right type of scan
     if args.project_type:
         project_types_list = args.project_type.split(",")
+    elif args.bom:
+        project_types_list = ["bom"]
     else:
         project_types_list = utils.detect_project_type(src_dir)
-    if "docker" in project_types_list:
+    if (
+        "docker" in project_types_list
+        or "podman" in project_types_list
+        or "container" in project_types_list
+        or "binary" in project_types_list
+    ):
         reports_base_dir = os.getcwd()
     db = dbLib.get()
     run_cacher = args.cache
@@ -245,8 +256,8 @@ def main():
     )
     reports_dir = os.path.dirname(areport_file)
     # Create reports directory
-    if not os.path.exists(reports_dir):
-        os.makedirs(reports_dir)
+    if reports_dir and not os.path.exists(reports_dir):
+        os.makedirs(reports_dir, exist_ok=True)
     if len(project_types_list) > 1:
         LOG.debug("Multiple project types found: {}".format(project_types_list))
     # Enable license scanning
@@ -255,7 +266,7 @@ def main():
         project_types_list.remove("license")
         console.print(
             Panel(
-                f"License audit is enabled for this scan. This would increase the time by up to 10 minutes.",
+                "License audit is enabled for this scan. This would increase the time by up to 10 minutes.",
                 title="License Audit",
                 expand=False,
             )
@@ -295,7 +306,8 @@ def main():
             scoped_pkgs = utils.get_pkgs_by_scope(project_type, pkg_list)
         if os.getenv("FETCH_LICENSE", "") in (True, "1", "true"):
             licenses_results = bulk_lookup(
-                build_license_data(license_data_dir), pkg_list=pkg_list
+                build_license_data(license_data_dir, spdx_license_list),
+                pkg_list=pkg_list,
             )
             license_report_file = os.path.join(
                 reports_dir, "license-" + project_type + ".json"
@@ -328,7 +340,6 @@ def main():
                 except Exception as e:
                     LOG.error(e)
                     LOG.error("Risk audit was not successful")
-                    risk_results = None
             else:
                 console.print(
                     Panel(
@@ -354,7 +365,7 @@ def main():
                 LOG.error(e)
                 results = None
         # In case of docker, check if there are any npm packages that can be audited remotely
-        if project_type in ("docker"):
+        if project_type in ("podman", "docker"):
             npm_pkg_list = get_pkg_by_type(pkg_list, "npm")
             if npm_pkg_list:
                 LOG.debug(f"No of packages {len(npm_pkg_list)}")
@@ -372,13 +383,9 @@ def main():
             LOG.debug(
                 "Vulnerability database loaded from {}".format(config.vdb_bin_file)
             )
-        sources_list = [NvdSource()]
+        sources_list = [OSVSource(), NvdSource()]
         if os.environ.get("GITHUB_TOKEN"):
             sources_list.insert(0, GitHubSource())
-        else:
-            LOG.info(
-                "To use GitHub advisory source please set the environment variable GITHUB_TOKEN!"
-            )
         if run_cacher:
             for s in sources_list:
                 LOG.debug("Refreshing {}".format(s.__class__.__name__))
