@@ -20,7 +20,11 @@ def exec_tool(args, cwd=None, stdout=subprocess.PIPE):
     """
     try:
         LOG.debug('⚡︎ Executing "{}"'.format(" ".join(args)))
-        subprocess.run(
+        if os.environ.get("FETCH_LICENSE"):
+            LOG.debug(
+                "License information would be fetched from the registry. This would take several minutes ..."
+            )
+        cp = subprocess.run(
             args,
             stdout=stdout,
             stderr=subprocess.STDOUT,
@@ -30,6 +34,7 @@ def exec_tool(args, cwd=None, stdout=subprocess.PIPE):
             shell=False,
             encoding="utf-8",
         )
+        LOG.debug(cp.stdout)
     except Exception as e:
         LOG.exception(e)
 
